Theme class

Constructors

Theme()

Properties

breakpoints ↔ ThemeBreakpoints
getter/setter pair
colors ↔ ThemeColors
getter/setter pair
components ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ String
getter/setter pair
typography ↔ ThemeTypography
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited