ThemeTypography class

Constructors

ThemeTypography()

Properties

body1 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
body2 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
body3 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
body4 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
body5 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
display1 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heading1 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
heading2 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
heading3 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
heading4 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
heading5 ↔ Map<Breakpoints, ThemeTypographySet>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited